@@ -9,7 +9,7 @@ from office.api import excel
 
 print('=' * 30)
 print('【python-office库】，功能持续更新中')
-print( '全部功能文档：https://www.python-office.com/')
+print( '全部功能 - 说明书 -：https://www.python-office.com/')
 print('使用有问题 or 提交你的功能需求 or 参与项目开发')
-print('请加入【项目交流群】：http://t.cn/A65MiFvH')
+print('请+【开发者微信】：http://t.cn/A6XVQXAk')
 print('=' * 30)
